package ar.edu.unju.fi.soo.champions.controller;

import java.util.HashMap;
import java.util.Map;
import java.util.NoSuchElementException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.dao.DataAccessException;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestController;

import ar.edu.unju.fi.soo.champions.service.SoccerService;
import ar.edu.unju.fi.soo.champions.service.dto.request.PlayerDTO;

/**
 * 
 * @author jzapana
 *
 */
@RestController
@RequestMapping("/api/v2/player")
@ResponseStatus(HttpStatus.SERVICE_UNAVAILABLE)
public class PlayerResource {
	private final Logger log = LoggerFactory.getLogger(TeamResource.class);
	@Autowired
	SoccerService soccerService;

	@PostMapping("/players")
	public ResponseEntity<?> savePlayerToTeam(@RequestBody PlayerDTO dto) {
		log.debug("API REST agregando un player al team [" + dto.getTeamId() + "]");
		Map<String, Object> response = new HashMap<String, Object>();
		try {

			response.put("Objeto", soccerService.addPlayerToTeam(dto));
			response.put("Mensaje", "Objeto creado correctamente");

		} catch (DataAccessException e) {
			response.put("Mensaje", "Error al guardar el objeto");
			response.put("Error", e.getMostSpecificCause().getMessage());
			return new ResponseEntity<Map<String, Object>>(response, HttpStatus.INTERNAL_SERVER_ERROR);
		}
		return new ResponseEntity<Map<String, Object>>(response, HttpStatus.CREATED);
	}

	@PutMapping("/players")
	public ResponseEntity<?> updatePlayerToTeam(@RequestBody PlayerDTO dto) {
		log.debug("API REST Modificando un player al team [" + dto.getTeamId() + "]");
		Map<String, Object> response = new HashMap<String, Object>();
		try {
			PlayerDTO player = soccerService.updatePlayer(dto);
			response.put("Objeto", player);
			response.put("Mensaje", "Objeto modificado correctamente");

		} catch (NoSuchElementException e) {
			response.put("Mensaje", "No existe el Id del objeto");
			return new ResponseEntity<Map<String, Object>>(response, HttpStatus.INTERNAL_SERVER_ERROR);
		} catch (DataAccessException e) {
			response.put("Mensaje", "Error al guardar el objeto");
			response.put("Error", e.getMostSpecificCause().getMessage());
			return new ResponseEntity<Map<String, Object>>(response, HttpStatus.INTERNAL_SERVER_ERROR);
		}
		return new ResponseEntity<Map<String, Object>>(response, HttpStatus.OK);
	}

}
